==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/lang/en/acp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'acp_overview'=>'Executive Overview',
'access_control'=>'Access Control',
'configuration'=>'Configuration',
'scheduled_task'=>'Scheduled Task',
'user_group'=>'User Group',
'post_prefix'=>'Post Prefix',
'log_view'=>'Log View',
'database_version_is_too_old_please_upgrade'=>'The current version of this software requires a more recent database structure than you have. Please rerun setup and update your database.',
'please_select_action'=>'Please select an action to edit',
'new_ace'=>'Add a new user to list',
'new_ace_successful'=>'A new access control entry has been inserted.',
'edit_acl'=>'Set Permissions',
'edit_acl_successful'=>'This access control list has been edited.',
'delete_ace_successful'=>'This access control entry has been removed.',
'ace_to_group'=>'To Group',
'ace_to_user'=>'To User',
'please_select_class'=>'Please select configuration area to edit',
'edit_cfg'=>'Set Options',
'edit_cfg_successful'=>'Your configuration has been edited.',
'scan_for_new_task'=>'Scan for new task files',
'installed_new_task'=>'Installed the following task(s)',
'no_new_task_found'=>'No new tasks were found...',
'please_select_task'=>'Please select a task to edit',
'task_seg_optimize'=>'Task: Optimize forum database',
'task_seg_post_timespan'=>'Task: Create main overview calendar',
'task_seg_prune_request'=>'Task: Prune user requests',
'task_seg_prune_search'=>'Task: Prune search table',
'task_seg_prune_user'=>'Task: Prune user accounts',
'task_explain_optimize'=>'Optimizes your database',
'task_explain_post_timespan'=>'Calculates the oldest/youngest posting',
'task_explain_prune_request'=>'Purges expired user requests from database',
'task_explain_prune_search'=>'Purges expired search results from database',
'task_explain_prune_user'=>'Purges not activated user accounts from database',
'edit_task'=>'Edit Task',
'task_active'=>'Run task',
'task_interval'=>'Run Interval',
'task_info'=>'Task Information',
'task_description'=>'Description',
'task_last_run'=>'Last run timestamp',
'task_next_run'=>'Next run (soonest)',
'explain_task_interval'=>'At what interval should this task be run? Value: <u>seconds</u>',
'edit_task_successful'=>'This task has been edited.',
'please_select_group'=>'Please select a user group to edit',
'color'=>'Color',
'group_id'=>'Group-ID',
'group_post_weight'=>'Highest Post Weight',
'group_permission_pa'=>'Group Permission: Post Approved',
'group_permission_pr'=>'Group Permission: Post Repeat',
'group_permission_ra'=>'Group Permission: Read Unapproved',
'group_permission_ex'=>'Group Permission: Executive',
'explain_group_name'=>'Set the name of this group.',
'explain_group_color'=>'This color is used to represent the group.',
'explain_group_post_weight'=>'Maximum weight for any submitted posting.',
'explain_group_permission_pa'=>'Should new postings be approved immediately?',
'explain_group_permission_ra'=>'Can this group read unapproved postings?',
'explain_group_permission_pr'=>'Is this group allowed to submit repeated postings?',
'explain_group_permission_ex'=>'Does this group have executive permissions?',
'edit_group'=>'Edit User Group',
'edit_group_successful'=>'This user group has been edited.',
'add_a_new_group'=>'Add a new user group',
'new_group_successful'=>'A new user group has been added.',
'group_is_not_empty'=>'This user group still has assigned members.',
'delete_group_successful'=>'This user group has been deleted.',
'please_select_prefix'=>'Please select a post prefix to edit',
'add_a_new_prefix'=>'Add a new post prefix',
'prefix_acl'=>'Access Control Preset',
'list_as_request'=>'Enlist it as Request',
'explain_prefix_name'=>'Set the name of this prefix.',
'explain_prefix_acl'=>'If this prefix is applied to a posting there permissions are inherited.',
'explain_list_as_request'=>'Do postings having this prefix be listed on moderation and executive panel as "pending request"?',
'edit_prefix'=>'Edit Prefix',
'edit_prefix_successful'=>'This post prefix has been edited.',
'new_prefix_successful'=>'A new post prefix has been added.',
'prefix_is_not_empty'=>'This post prefix still has assigned postings.',
'delete_prefix_successful'=>'This post prefix has been deleted.',
'quick_overview'=>'What is happening in short...',
'pending_requests'=>'Current pending requests',
'forum_running'=>'Forum is running',
'next_task'=>'Next scheduled task',
'version'=>'Current version',
'run_soonest'=>'soonest on',
'recent_log_entries'=>'Recent logged actions',
'stat_user_registered_today'=>'Users have registered today',
'stat_user_total'=>'Total amount of registered user accounts',
'stat_user_request_total'=>'Number of pending user requests',
'stat_post_total'=>'Currently stored postings',
'choose_time'=>'Choose Time',
'choose_level'=>'Choose Level',
'choose_ip'=>'Limit to IP-Address',
'choose_zoom'=>'Time Series',
'choose_data'=>'Choose data',
'explain_choose_time'=>'Choose a time.',
'explain_choose_level'=>'Limit results to a level?',
'explain_user'=>'Limit results to an user?',
'explain_choose_ip'=>'Limit results to an IP-Address?',
'explain_order_by'=>'Select how to order results.',
'log_level'=>'Log Level',
'log_action'=>'Log Action',
'ip_address'=>'IP-Address',
'statistic'=>'Statistic',
'monthly'=>'Monthly',
'yearly'=>'Yearly',
'log_level_both'=>'Both',
'log_level_info'=>'Info',
'log_level_error'=>'Error',
'log_info'=>'Information',
'log_text'=>'Message',
'statistic_data_login'=>'Number of Logins',
'statistic_data_account'=>'Registered Accounts',
'statistic_data_password'=>'Requested Passwords',
'statistic_data_search'=>'Search Queries',
'statistic_data_posting'=>'Submitted Postings',
'statistic_data_exception'=>'Software Exceptions',
'st_login_attempt'=>'Login Attempt',
'st_login_success'=>'Login Success',
'st_account_register'=>'Account Registered',
'st_account_activation'=>'Account Activated',
'st_password_request'=>'Password Request',
'st_password_activation'=>'Password Activated',
'st_search_query'=>'Search Queries Issued',
'st_search_cached'=>'Fetched from Cache',
'st_submit_posting'=>'Submitted Posting',
'st_exception'=>'Software Exception'
);
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/lang/en/acp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'acp_overview'=>'Executive Overview',
'access_control'=>'Access Control',
'configuration'=>'Configuration',
'scheduled_task'=>'Scheduled Task',
'user_group'=>'User Group',
'post_prefix'=>'Post Prefix',
'log_view'=>'Log View',
'database_version_is_too_old_please_upgrade'=>'The current version of this software requires a more recent database structure than you have. Please rerun setup and update your database.',
'select_time'=>'Select Time',
'select_color'=>'Select Color',
'purge_acl_cache'=>'Purge ACL Cache',
'please_select_action'=>'Please select an action to edit',
'new_ace'=>'Add a new user to list',
'new_ace_successful'=>'A new access control entry has been inserted.',
'edit_acl'=>'Set Permissions',
'edit_acl_successful'=>'This access control list has been edited.',
'delete_ace_successful'=>'This access control entry has been removed.',
'ace_to_group'=>'To Group',
'ace_to_user'=>'To User',
'purge_main_cache'=>'Purge Main Cache',
'please_select_class'=>'Please select configuration area to edit',
'edit_cfg'=>'Set Options',
'edit_cfg_successful'=>'Your configuration has been edited.',
'scan_for_new_task'=>'Scan for new task files',
'installed_new_task'=>'Installed the following task(s)',
'no_new_task_found'=>'No new tasks were found...',
'please_select_task'=>'Please select a task to edit',
'task_seg_optimize'=>'Task: Optimize forum database',
'task_seg_post_timespan'=>'Task: Create main overview calendar',
'task_seg_prune_request'=>'Task: Prune user requests',
'task_seg_prune_search'=>'Task: Prune search table',
'task_seg_prune_user'=>'Task: Prune user accounts',
'task_explain_optimize'=>'Optimizes your database',
'task_explain_post_timespan'=>'Calculates the oldest/youngest posting',
'task_explain_prune_request'=>'Purges expired user requests from database',
'task_explain_prune_search'=>'Purges expired search results from database',
'task_explain_prune_user'=>'Purges not activated user accounts from database',
'edit_task'=>'Edit Task',
'task_active'=>'Run task',
'task_interval'=>'Run Interval',
'task_info'=>'Task Information',
'task_description'=>'Description',
'task_last_run'=>'Last run timestamp',
'task_next_run'=>'Next run (soonest)',
'explain_task_interval'=>'At what interval should this task be run? Value: <u>seconds</u>',
'edit_task_successful'=>'This task has been edited.',
'please_select_group'=>'Please select a user group to edit',
'color'=>'Color',
'group_id'=>'Group-ID',
'group_post_weight'=>'Highest Post Weight',
'group_permission_copy'=>'Copy Group Permission',
'group_permission_pa'=>'Group Permission: Post Approved',
'group_permission_pr'=>'Group Permission: Post Repeat',
'group_permission_ra'=>'Group Permission: Read Unapproved',
'group_permission_ex'=>'Group Permission: Executive',
'explain_group_name'=>'Set the name of this group.',
'explain_group_color'=>'This color is used to represent the group.',
'explain_group_post_weight'=>'Maximum weight for any submitted posting.',
'explain_group_permission_copy'=>'Select a group you want to copy the permissions from to the new one.',
'explain_group_permission_pa'=>'Should new postings be approved immediately?',
'explain_group_permission_ra'=>'Can this group read unapproved postings?',
'explain_group_permission_pr'=>'Is this group allowed to submit repeated postings?',
'explain_group_permission_ex'=>'Does this group have executive permissions?',
'edit_group'=>'Edit User Group',
'edit_group_successful'=>'This user group has been edited.',
'add_a_new_group'=>'Add a new user group',
'new_group_successful'=>'A new user group has been added.',
'group_is_not_empty'=>'This user group still has assigned members.',
'delete_group_successful'=>'This user group has been deleted.',
'please_select_prefix'=>'Please select a post prefix to edit',
'add_a_new_prefix'=>'Add a new post prefix',
'prefix_acl'=>'Access Control Preset',
'list_as_request'=>'Enlist it as Request',
'explain_prefix_name'=>'Set the name of this prefix.',
'explain_prefix_acl'=>'If this prefix is applied to a posting these permissions are inherited.',
'explain_list_as_request'=>'Do postings having this prefix be listed on moderation and executive panel as "pending request"?',
'edit_prefix'=>'Edit Prefix',
'edit_prefix_successful'=>'This post prefix has been edited.',
'new_prefix_successful'=>'A new post prefix has been added.',
'prefix_is_not_empty'=>'This post prefix still has assigned postings.',
'delete_prefix_successful'=>'This post prefix has been deleted.',
'forum_is_not_running'=>'This forum is set to maintenance mode. Only privileged users can access it.',
'new_forum_software_version_available'=>'The update server reports a <a href="%s" target="_blank">new version (%s)</a> is available for download.',
'quick_overview'=>'What is happening in short...',
'pending_requests'=>'Current pending requests',
'next_task'=>'Next scheduled task',
'version'=>'Current version',
'php_version'=>'PHP Version',
'database_version'=>'Database Version',
'check_for_update'=>'Check for Software Update',
'run_soonest'=>'soonest on',
'stat_user_registered_today'=>'Users have registered today',
'stat_user_total'=>'Total amount of registered user accounts',
'stat_user_request_total'=>'Number of pending user requests',
'stat_post_total'=>'Currently stored postings',
'choose_time'=>'Choose Time',
'choose_level'=>'Choose Level',
'choose_ip'=>'Limit to IP-Address',
'choose_zoom'=>'Time Series',
'choose_data'=>'Choose data',
'explain_choose_time'=>'Choose a time.',
'explain_choose_level'=>'Limit results to a level?',
'explain_user'=>'Limit results to an user?',
'explain_choose_ip'=>'Limit results to an IP-Address?',
'explain_order_by'=>'Select how to order results.',
'log_level'=>'Log Level',
'log_action'=>'Log Action',
'ip_address'=>'IP-Address',
'statistic'=>'Statistic',
'monthly'=>'Monthly',
'yearly'=>'Yearly',
'log_level_both'=>'Both',
'log_level_info'=>'Info',
'log_level_error'=>'Error',
'log_info'=>'Information',
'log_text'=>'Message',
'statistic_data_login'=>'Number of Logins',
'statistic_data_account'=>'Registered Accounts',
'statistic_data_password'=>'Requested Passwords',
'statistic_data_search'=>'Search Queries',
'statistic_data_posting'=>'Submitted Postings',
'statistic_data_exception'=>'Software Exceptions',
'st_login_attempt'=>'Login Attempt',
'st_login_success'=>'Login Success',
'st_account_register'=>'Account Registered',
'st_account_activation'=>'Account Activated',
'st_password_request'=>'Password Request',
'st_password_activation'=>'Password Activated',
'st_search_query'=>'Search Queries Issued',
'st_search_cached'=>'Fetched from Cache',
'st_submit_posting'=>'Submitted Posting',
'st_exception'=>'Software Exception'
);
?>
